# Generated by Django 2.2.7 on 2019-12-30 09:04

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0029_release_pipeline_run_created_at_ordering"),
    ]

    operations = [
        migrations.AlterUniqueTogether(name="credential", unique_together={("name", "team")},),
    ]
