# Generated by Django 2.2.6 on 2019-11-04 02:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0023_auto_20191024_0825"),
    ]

    operations = [
        migrations.AddField(model_name="scmsteprun", name="ended", field=models.DateTimeField(blank=True, null=True),),
        migrations.AddField(
            model_name="scmsteprun", name="started", field=models.DateTimeField(blank=True, null=True),
        ),
    ]
