# Generated by Django 2.2.6 on 2019-11-15 10:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0027_commit_ordering"),
    ]

    operations = [
        migrations.AddConstraint(
            model_name="scmpipelinerun",
            constraint=models.UniqueConstraint(
                fields=("commit_hash", "application"), name="unique commits per application"
            ),
        ),
    ]
