# Generated by Django 2.2.7 on 2020-01-06 12:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0030_unique_team_credentialname"),
    ]

    operations = [
        migrations.AddField(model_name="application", name="active", field=models.BooleanField(default=True),),
    ]
