# Generated by Django 2.1.5 on 2019-04-14 11:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0012_scmrelease"),
    ]

    operations = [
        migrations.AlterField(
            model_name="scmsteprun",
            name="status",
            field=models.CharField(
                choices=[
                    ("not started", "not started"),
                    ("in progress", "in progress"),
                    ("waiting", "waiting"),
                    ("skipped", "skipped"),
                    ("failed", "failed"),
                    ("success", "success"),
                ],
                default="in progress",
                max_length=30,
            ),
        ),
    ]
