# Generated by Django 2.2.6 on 2019-10-21 06:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0020_multiple_pipeline_runs_per_release"),
    ]

    operations = [
        migrations.AddField(model_name="scmsteprun", name="tags", field=models.TextField(blank=True),),
    ]
