# Generated by Django 2.2.7 on 2019-11-07 14:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("katka", "0025_datetime_field_names"),
    ]

    operations = [
        migrations.AddField(
            model_name="scmsteprun", name="step_type", field=models.CharField(max_length=100, null=True),
        ),
    ]
